@@ -13,7 +13,7 @@ pub fn buggy_sort(xs: &mut [u8]) {
 mod tests {
     use super::*;
 
-    use arbtest::arbitrary::Unstructured;
+    use arbtest::arbitrary::{self, Unstructured};
 
     fn prop(u: &mut Unstructured<'_>) -> arbitrary::Result<()> {
         let mut xs = u.arbitrary::<Vec<u8>>()?;
